@@ -8,14 +8,14 @@
 @Describe : Define analysis global variables
 """
 import os
-from facrsa_code.library.util.configUtil import get_config
+from pathlib import Path
 
 
 def return_config(factor, mail, private_plugin, uid, tid):
-    base_path = get_config('storage')["local_path"] + "/facrsa_code/upload/" + str(uid) + "/" + str(tid) + "/"
+    base_path = Path(os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__)))),"static/upload",str(uid),str(tid)).as_posix()
     initial_path = base_path + "/initial/"
-    predict_out_path = base_path + "predictout/"
-    out_path = base_path + "output/"
+    predict_out_path = base_path + "/predictout/"
+    out_path = base_path + "/output/"
     # private_plugin = get_config('storage')["local_path"] + "/" + str(uid) + "/" + str(tid) + "/"
     length_ratio = factor
     area_ratio = factor * factor
